<?php
/*
Plugin Name: SimplePie for Wordpress
Version: 1.2.1
Plugin URI: http://simplepie.org/wiki/plugins/wordpress/simplepie_plugin_for_wordpress
Description: Wordpress plugin for SimplePie: a super-fast, easy-to-use RSS and Atom parser.
Author: Ryan Parman and Geoffrey Sneddon
Author URI: http://simplepie.org/
*/

// Include the required SimplePie library.
require('simplepie.inc');

$path = explode($_SERVER['SERVER_NAME'], get_bloginfo('wpurl'));
$cache_dir = $_SERVER['DOCUMENT_ROOT'] . $path[1] . '/wp-content/plugins/cache';
define('SIMPLEPIE_CACHEDIR', $cache_dir);

function SimplePieWP($input, $options='') {
	$argv=Array();
	$options = explode(',', $options);
	foreach($options as $option) {
		$opt = explode(':', trim($option));
		if (strtolower($opt[0]) == 'items') $argv['items']=$opt[1];
		else if (strtolower($opt[0]) == 'showdesc') $argv['showdesc']=$opt[1];
		else if (strtolower($opt[0]) == 'showdate') $argv['showdate']=$opt[1];
		else if (strtolower($opt[0]) == 'shortdesc') $argv['shortdesc']=$opt[1];
		else if (strtolower($opt[0]) == 'error') $argv['error']=$opt[1];
		else if (strtolower($opt[0]) == 'showtitle') $argv['showtitle']=$opt[1];
		else if (strtolower($opt[0]) == 'alttitle') $argv['alttitle']=$opt[1];
	}

	$feed = new SimplePie();
	$feed->set_feed_url($input);
	$feed->set_cache_location(SIMPLEPIE_CACHEDIR);
	$success = $feed->init();

	if ($success && $feed->data) {
		$flink = $feed->get_permalink();
		$ftitle = $feed->get_title();

		$output='';
		$output .= '<div class="simplepie">';
		if (!isset($argv['showtitle']) || empty($argv['showtitle']) || $argv['showtitle'] == "true") {
			if (isset($argv['alttitle']) && !empty($argv['alttitle'])) {
				if ($ftitle != '' && $flink != '') $output .= "<h3><a href=\"$flink\">" . $argv['alttitle'] . "</a></h3>";
				else if ($ftitle != '') $output .= "<h3>" . $argv['alttitle'] . "</h3>";
			}
			else {
				if ($ftitle != '' && $flink != '') $output .= "<h3><a href=\"$flink\">$ftitle</a></h3>";
				else if ($ftitle != '') $output .= "<h3>$ftitle</h3>";
			}
		}
		$output .= '<ol>';

		$max = $feed->get_item_quantity();
		if (isset($argv['items']) && !empty($argv['items'])) $max = min($argv['items'], $feed->get_item_quantity());

		for($x=0; $x<$max; $x++) {
			$item = $feed->get_item($x);
			$link = $item->get_permalink();
			$title = StupefyEntities($item->get_title());
			$full_desc = StupefyEntities($item->get_description());
			$desc = $full_desc;

			if (isset($argv['shortdesc']) && !empty($argv['shortdesc'])) {
				$suffix = '...';
				$short_desc = trim(str_replace("\n", ' ', str_replace("\r", ' ', strip_tags(StupefyEntities($item->get_description())))));
				$desc = substr($short_desc, 0, $argv['shortdesc']);
				$lastchar = substr($desc, -1, 1);
				if ($lastchar == '.' || $lastchar == '!' || $lastchar == '?') $suffix='';
				$desc .= $suffix;
			}

			if (isset($argv['showdesc']) && !empty($argv['showdesc']) && $argv['showdesc']==='false') {
				if (isset($argv['showdate']) && !empty($argv['showdate'])) {
					$output .= "<li><a href=\"$link\">$title</a> <span class=\"date\">" . $item->get_date($argv['showdate']) . "</span></li>";
				} else {
					$output .= "<li><a href=\"$link\">$title</a></li>";
				}
			} else {
				if (isset($argv['showdate']) && !empty($argv['showdate'])) {
					$output .= "<li><strong><a href=\"$link\">$title</a> <span class=\"date\">" . $item->get_date($argv['showdate']) . "</span></strong><br />$desc</li>";
				} else {
					$output .= "<li><strong><a href=\"$link\">$title</a></strong><br />$desc</li>";
				}
			}
		}

		$output .= '</ol>';
		$output .= '</div>';
	}
	else {
		if (isset($argv['error']) && !empty($argv['error'])) $output = $argv['error'];
		else if (isset($feed->error)) $output = $feed->error;
	}

	return $output;
}

// SmartyPants 1.5.1 changes rolled in May 2004 by Alex Rosenberg, http://monauraljerk.org/smartypants-php/
function StupefyEntities($s = '') {
	$inputs = array('&#8211;', '&#8212;', '&#8216;', '&#8217;', '&#8220;', '&#8221;', '&#8230;', '&#91;', '&#93;');
	$outputs = array('-', '--', "'", "'", '"', '"', '...', '[', ']');
	$s = str_replace($inputs, $outputs, $s);
	return $s;
}

?>
